import time
import iptc

TIME_INTERVEL = 0.3
NAME_SSINPUT  = "SS-PY-INPUT"
NAME_SSOUTPUT = "SS-PY-OUTPUT"

class IPTable(object):
    def __init__(self):
        self.initChain()

    def __insertRule(self, chain, dport, sport, protocol, mode):
        rule           = iptc.Rule()
        rule.protocol  = protocol
        match          = iptc.Match(rule,protocol)
        match.protocol = protocol
        match.dport    = dport
        match.sport    = sport
        rule.add_match(match)
        target      = iptc.Target(rule, mode)
        rule.target = target
        chain.insert_rule(rule)

    def delChain(self):
        table = iptc.Table(iptc.Table.FILTER)
        table.delete_chain(NAME_SSINPUT)
        table.delete_chain(NAME_SSOUTPUT)
        self.input  = None
        self.output = None

    def initChain(self):
        self.delChain()
        table       = iptc.Table(iptc.Table.FILTER)
        self.input  = table.create_chain(NAME_SSINPUT)
        self.output = table.create_chain(NAME_SSOUTPUT)
    
    def addPortRule(self, port, isRejct=False):
        mode = "ACCEPT"
        if isRejct:
            mode = "REJECT"
        self.__insertRule(self.input, port, None, "tcp", mode)
        self.__insertRule(self.input, port, None, "udp", mode)
        self.__insertRule(self.output, None, port, "tcp", mode)
        self.__insertRule(self.output, None, port, "udp", mode)
    
    def deletePortRule(self, port, isRejct=False):
        pass



from aigpy import cmdHelper
from aigpy import convertHelper
from ss_py.sstool import SSTool

def printMenu(tool):
    print('======================')
    cmdHelper.myprint('1.  ',cmdHelper.TextColor.Green)
    print('启动')
    cmdHelper.myprint('2.  ',cmdHelper.TextColor.Green)
    print('停止')
    cmdHelper.myprint('3.  ',cmdHelper.TextColor.Green)
    print('菜单')
    print('-------------')
    cmdHelper.myprint('4.  ',cmdHelper.TextColor.Green)
    print('添加用户')
    cmdHelper.myprint('5.  ',cmdHelper.TextColor.Green)
    print('删除用户')
    cmdHelper.myprint('6.  ',cmdHelper.TextColor.Green)
    print('显示用户')
    print('')
    tool.printStatus()
    print('======================')

def main(argv=None):
    tool = SSTool()
    printMenu(tool)
    while True:
        cmdHelper.myprint('输入选择(3显示菜单):',cmdHelper.TextColor.Yellow)
        choice = cmdHelper.myinputInt('',9999)
        if choice == 1:
            tool.startSS()
            tool.printStatus()
        elif choice == 2:
            tool.stopSS()
            tool.printStatus()
        elif choice == 3:
            printMenu(tool)
        elif choice == 4:
            port  = cmdHelper.myinputInt('端口:', -1)
            pwd   = cmdHelper.myinput('密码:')
            limit = cmdHelper.myinputInt('流量(G):', 1)
            limit = convertHelper.convertStorageUnit(limit, 'gb', 'byte')
            tool.addDelPort(True, port, pwd, limit)
        elif choice == 5:
            port = cmdHelper.myinputInt('端口:', -1)
            tool.addDelPort(False, port, None, None)
        elif choice == 6:
            tool.printPorts()

def main2(argv=None):
    pass


__all__ = ['main', 'main2']
